//
//  Note.swift
//  ListsStoryboard
//
//  Created by Roman Vyjídáček on 16.03.2023.
//

import Foundation

struct Note: Identifiable {
    
    var id: String
    var title: String
    var content: String
}

extension Array where Element == Note {
    
    static var mock: [Note] {
        return (1...100).map {
            let randomLength = Int.random(in: 10..<String.loremIpsum.count)
            
            return .init(id: UUID().uuidString,
                         title: "Note \($0)",
                         content: .loremIpsum.trunc(length: randomLength))
        }
    }
}


extension String {
    
    static var loremIpsum: String {
        return "Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Nulla non arcu lacinia neque faucibus fringilla. Mauris metus. Nunc auctor. Phasellus enim erat, vestibulum vel, aliquam a, posuere eu, velit. Pellentesque arcu. Sed vel lectus. Donec odio tempus molestie, porttitor ut, iaculis quis, sem. Phasellus rhoncus. Aliquam erat volutpat. Maecenas lorem. Quisque porta. Phasellus et lorem id felis nonummy placerat. Integer malesuada. Curabitur bibendum justo non orci. In rutrum. Etiam bibendum elit eget erat."
    }
    
    func trunc(length: Int, trailing: String = "…") -> String {
        return (self.count > length) ? self.prefix(length) + trailing : self
    }

}
